This is an instrument driver library 
It is aimed at PhDs in photonics who are comfortable with developing python code
It is developed by Rastko Pajković at TU/e
It will remain as simple as possible, if you want to complex, complexify away

To install just 'pip install instrumess'

Credits:
- pymeasure package
- Dima Pustakhod and phiola package
- Perry van Schijk
- Stefanos Andreou